@@ -14,7 +14,7 @@ def manage():
         dotenv_path = find_dotenv(
             filename=dotenv_filename,
             raise_error_if_not_found=True,
-            usecwd=True
+            usecwd=False
         )
         print('Load dotenv configuration from %s' % dotenv_path)
         load_dotenv(dotenv_path=dotenv_path, override=True)
